==> nodejs-jumpstart-0.1.2.tgz: package/README.md <==
```
      __   __   ___        __
|\ | /  \ |  \ |__      | /__`
| \| \__/ |__/ |___ .\__/ .__/
                 __   __  ___       __  ___
   | |  |  |\/| |__) /__`  |   /\  |__)  |
\__/ \__/  |  | |    .__/  |  /~~\ |  \  |
```

## Summary

Node.JS Jumpstart is a sample repository that is used as an example for setting up a Node.JS sample project.

There’s nothing complicated here. It is just a sample repository that does some basic mathematical computations (*like calculating the average of a list of numbers*).

In the future it *may* evolve to something more involve into a starter kit maybe. — Though for now, it is just a sample demo repository.

## About This Repository

This repository is a part of [Byte-Sized JavaScript Bi-Weekly VideoCast][vidcast].

```
  _               __
 |_)   _|_  _ __ (_  o _   _   _|
 |_) \/ |_ (/_   __) | /_ (/__(_|
     /        |  _.     _. (_   _ ._ o ._ _|_
            \_| (_| \/ (_| __) (_ |  | |_) |_
                                       |
            »»  bit.ly/bytesized  ««
```

## Byte-Sized What?!

[Byte-Sized JavaScript][vidcast].

It is a compilation of short (*more or less ten minutes long*) monthly screencasts about **JavaScript** and related technologies.

## Wanna Help?

Any help is more than appreciated.

If you want to contribute to the source code, **fork this repository** and **create a pull request**.

> In lieu of a formal style guide, take care to maintain the existing coding style.

Also, don’t forget to add unit tests for any new or changed functionality.

If you want to report a bug; or share a comment or suggestion, [file an issue](https://github.com/jsbites/nodejs-jumpstart/issues/new).

## I’ve Found a Bug; I Have an Idea

[For bug reports and suggestions, please file an issue](https://github.com/jsbites/node-js-jumpstart/issues/new).

## Contact Information

* **Project Maintainer**: [Volkan Özçelik](https://volkan.io/)
* **Project Website**: [bytesized.tv](https://bytesized.tv/)

## Code of Conduct

We are committed to making participation in this project a harassment-free experience for everyone, regardless of the level of experience, gender, gender identity and expression, sexual orientation, disability, personal appearance, body size, race, ethnicity, age, religion, or nationality.

[See the code of conduct for details](CODE_OF_CONDUCT.md).

[vidcast]: https://bytesized.tv/ "ByteSized.TV"

==> nodejs-jumpstart-0.1.4.tgz: package/README.md <==
```
      __   __   ___        __
|\ | /  \ |  \ |__      | /__`
| \| \__/ |__/ |___ .\__/ .__/
                 __   __  ___       __  ___
   | |  |  |\/| |__) /__`  |   /\  |__)  |
\__/ \__/  |  | |    .__/  |  /~~\ |  \  |
```

## Summary

**Node.js Jumpstart** is a sample repository that is used as an example for setting up a [**Node.js**][node] sample project.

There’s nothing complicated here. It is just a sample repository that does some basic mathematical computations (*like calculating the average of a list of numbers*).

In the future it *may* evolve to something more involve into a starter kit maybe. — Though for now, it is just a sample demo repository.

## About This Repository

This repository is a part of [Byte-Sized JavaScript Bi-Weekly VideoCast][vidcast].

```
  _               __
 |_)   _|_  _ __ (_  o _   _   _|
 |_) \/ |_ (/_   __) | /_ (/__(_|
     /        |  _.     _. (_   _ ._ o ._ _|_
            \_| (_| \/ (_| __) (_ |  | |_) |_
                                       |
            »»  bit.ly/bytesized  ««
```

## Byte-Sized What?!

[Byte-Sized JavaScript][vidcast].

It is a compilation of short (*more or less ten minutes long*) monthly screencasts about **JavaScript** and related technologies.

## Wanna Help?

Any help is more than appreciated.

If you want to contribute to the source code, **fork this repository** and **create a pull request**.

> In lieu of a formal style guide, take care to maintain the existing coding style.

Also, don’t forget to add unit tests for any new or changed functionality.

If you want to report a bug; or share a comment or suggestion, [file an issue](https://github.com/jsbites/nodejs-jumpstart/issues/new).

## I’ve Found a Bug; I Have an Idea

[For bug reports and suggestions, please file an issue](https://github.com/jsbites/node-js-jumpstart/issues/new).

## Contact Information

* **Project Maintainer**: [Volkan Özçelik](https://volkan.io/)
* **Project Website**: [bytesized.tv](https://bytesized.tv/)

## Code of Conduct

We are committed to making participation in this project a harassment-free experience for everyone, regardless of the level of experience, gender, gender identity and expression, sexual orientation, disability, personal appearance, body size, race, ethnicity, age, religion, or nationality.

[See the code of conduct for details](CODE_OF_CONDUCT.md).

[vidcast]: https://bytesized.tv/ "ByteSized.TV"
[node]: https://nodejs.org/ "Node.js"
